@@ -53,13 +53,15 @@ from .lazyfunkwhalealbum import LazyfunkwhalealbumCommand
 from .matchmaking import MatchmakingCommand
 from .cvstats import CvstatsCommand
 from .elevatormusic import ElevatormusicCommand
-from .royalpack import RoyalpackCommand
+from .royalpackversion import RoyalpackCommand
 from .givefiorygi import GivefiorygiCommand
 from .help import HelpCommand
 from .pug import PugCommand
 from .magicktreasure import MagicktreasureCommand
 from .treasure import TreasureCommand
 from .givetreasure import GivetreasureCommand
+from .cat import CatCommand
+from .ping import PingCommand
 
 # Enter the commands of your Pack here!
 available_commands = [
@@ -124,6 +126,8 @@ available_commands = [
     MagicktreasureCommand,
     TreasureCommand,
     GivetreasureCommand,
+    CatCommand,
+    PingCommand,
 ]
 
 # Don't change this, it should automatically generate __all__
