@@ -1,9 +1,7 @@
 from .royalqueue import RoyalQueue
-from .finduser import find_user_api
 from .royalpool import RoyalPool
 
 __all__ = [
     "RoyalQueue",
-    "find_user_api",
     "RoyalPool",
 ]
